@@ -9,7 +9,7 @@ parser.add_option("-t", "--template", dest="template", help="base project templa
 parser.add_option("-c", "--config", dest="config", help="yaml file to provide setup variables", default="config.yaml")
 (options, args) = parser.parse_args()
 
-template_dir = os.path.join(kickstart.__path__[0], options.template)
+template_dir = os.path.join(kickstart.__path__[0], 'templates', options.template)
 
 config = {}
 config['project'] = re.sub('\-', '_', args[0])
